@@ -23,14 +23,20 @@
 package engine
 
 import (
-	_ "embed"
+	"archive/zip"
+	"bytes"
 	"fmt"
+	"io"
 	"math"
+	"os"
+	"path/filepath"
 	"strconv"
 	"strings"
 	"unicode/utf8"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/ansi"
+	fontCLI "github.com/jandedobbeleer/oh-my-posh/src/font"
+	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/regex"
 
 	"github.com/esimov/stackblur-go"
@@ -39,6 +45,14 @@ import (
 	"golang.org/x/image/font"
 )
 
+type ConnectionError struct {
+	reason string
+}
+
+func (f *ConnectionError) Error() string {
+	return f.reason
+}
+
 const (
 	red    = "#ED655A"
 	yellow = "#E1C04C"
@@ -67,6 +81,7 @@ const (
 	overlineReset       = "overliner"
 	strikethrough       = "strikethrough"
 	strikethroughReset  = "strikethroughr"
+	backgroundReset     = "backgroundr"
 	color16             = "color16"
 	left                = "left"
 	lineChange          = "linechange"
@@ -74,15 +89,6 @@ const (
 	link                = "link"
 )
 
-//go:embed font/Hack-Nerd-Bold.ttf
-var hackBold []byte
-
-//go:embed font/Hack-Nerd-Regular.ttf
-var hackRegular []byte
-
-//go:embed font/Hack-Nerd-Italic.ttf
-var hackItalic []byte
-
 type RGB struct {
 	r int
 	g int
@@ -109,6 +115,8 @@ type ImageRenderer struct {
 	BgColor       string
 	Ansi          *ansi.Writer
 
+	env platform.Environment
+
 	Path string
 
 	factor float64
@@ -139,40 +147,35 @@ type ImageRenderer struct {
 	ansiSequenceRegexMap map[string]string
 }
 
-func (ir *ImageRenderer) Init(config string) {
+func (ir *ImageRenderer) Init(env platform.Environment) error {
+	ir.env = env
+
 	if ir.Path == "" {
-		match := regex.FindNamedRegexMatch(`.*(\/|\\)(?P<STR>.+)\.(json|yaml|yml|toml)`, config)
+		match := regex.FindNamedRegexMatch(`.*(\/|\\)(?P<STR>.+)\.(json|yaml|yml|toml)`, env.Flags().Config)
 		ir.Path = fmt.Sprintf("%s.png", strings.TrimSuffix(match[str], ".omp"))
 	}
 
-	f := 2.0
-
 	ir.cleanContent()
 
-	fontRegular, _ := truetype.Parse(hackRegular)
-	fontBold, _ := truetype.Parse(hackBold)
-	fontItalic, _ := truetype.Parse(hackItalic)
-	fontFaceOptions := &truetype.Options{Size: f * 12, DPI: 144}
+	if err := ir.loadFonts(); err != nil {
+		return &ConnectionError{reason: err.Error()}
+	}
 
 	ir.defaultForegroundColor = &RGB{255, 255, 255}
 	ir.defaultBackgroundColor = &RGB{21, 21, 21}
 
-	ir.factor = f
-
+	ir.factor = 2.0
 	ir.columns = 80
 	ir.rows = 25
 
-	ir.margin = f * 48
-	ir.padding = f * 24
+	ir.margin = ir.factor * 48
+	ir.padding = ir.factor * 24
 
 	ir.shadowBaseColor = "#10101066"
-	ir.shadowRadius = uint8(math.Min(f*16, 255))
-	ir.shadowOffsetX = f * 16
-	ir.shadowOffsetY = f * 16
+	ir.shadowRadius = uint8(math.Min(ir.factor*16, 255))
+	ir.shadowOffsetX = ir.factor * 16
+	ir.shadowOffsetY = ir.factor * 16
 
-	ir.regular = truetype.NewFace(fontRegular, fontFaceOptions)
-	ir.bold = truetype.NewFace(fontBold, fontFaceOptions)
-	ir.italic = truetype.NewFace(fontItalic, fontFaceOptions)
 	ir.lineSpacing = 1.2
 
 	ir.ansiSequenceRegexMap = map[string]string{
@@ -192,12 +195,88 @@ func (ir *ImageRenderer) Init(config string) {
 		overlineReset:       `^(?P<STR>\x1b\[55m)`,
 		strikethrough:       `^(?P<STR>\x1b\[9m)`,
 		strikethroughReset:  `^(?P<STR>\x1b\[29m)`,
+		backgroundReset:     `^(?P<STR>\x1b\[49m)`,
 		color16:             `^(?P<STR>\x1b\[(?P<BC>[349][0-7]|10[0-7]|39)m)`,
 		left:                `^(?P<STR>\x1b\[(\d{1,3})D)`,
 		lineChange:          `^(?P<STR>\x1b\[(\d)[FB])`,
 		consoleTitle:        `^(?P<STR>\x1b\]0;(.+)\007)`,
 		link:                fmt.Sprintf(`^%s`, regex.LINK),
 	}
+
+	return nil
+}
+
+func (ir *ImageRenderer) loadFonts() error {
+	var data []byte
+
+	fontCachePath := filepath.Join(ir.env.CachePath(), "Hack.zip")
+	if _, err := os.Stat(fontCachePath); err == nil {
+		data, _ = os.ReadFile(fontCachePath)
+	}
+
+	// Download font if not cached
+	if data == nil {
+		url := "https://github.com/ryanoasis/nerd-fonts/releases/download/v3.0.0/Hack.zip"
+		var err error
+
+		data, err = fontCLI.Download(url)
+		if err != nil {
+			return err
+		}
+
+		err = os.WriteFile(fontCachePath, data, 0644)
+		if err != nil {
+			return err
+		}
+	}
+
+	bytesReader := bytes.NewReader(data)
+	zipReader, err := zip.NewReader(bytesReader, int64(bytesReader.Len()))
+	if err != nil {
+		return err
+	}
+
+	fontFaceOptions := &truetype.Options{Size: 2.0 * 12, DPI: 144}
+
+	parseFont := func(file *zip.File) (font.Face, error) {
+		rc, err := file.Open()
+		if err != nil {
+			return nil, err
+		}
+
+		defer rc.Close()
+
+		data, err := io.ReadAll(rc)
+		if err != nil {
+			return nil, err
+		}
+
+		font, err := truetype.Parse(data)
+		if err != nil {
+			return nil, err
+		}
+
+		return truetype.NewFace(font, fontFaceOptions), nil
+	}
+
+	for _, file := range zipReader.File {
+		switch file.Name {
+		case "HackNerdFont-Regular.ttf":
+			if regular, err := parseFont(file); err == nil {
+				ir.regular = regular
+			}
+		case "HackNerdFont-Bold.ttf":
+			if bold, err := parseFont(file); err == nil {
+				ir.bold = bold
+			}
+		case "HackNerdFont-Italic.ttf":
+			if italic, err := parseFont(file); err == nil {
+				ir.italic = italic
+			}
+		}
+	}
+
+	return nil
 }
 
 func (ir *ImageRenderer) fontHeight() float64 {
@@ -220,7 +299,7 @@ var doubleWidthRunes = []RuneRange{
 	// Font Awesome Extension
 	{Start: '\ue200', End: '\ue2a9'},
 	// Material Design Icons
-	{Start: '\uf500', End: '\ufd46'},
+	{Start: '\U000f0001', End: '\U000f0848'},
 	// Weather
 	{Start: '\ue300', End: '\ue3eb'},
 	// Octicons
@@ -497,6 +576,9 @@ func (ir *ImageRenderer) shouldPrint() bool {
 			ir.foregroundColor = ir.defaultForegroundColor
 			ir.backgroundColor = nil
 			return false
+		case backgroundReset:
+			ir.backgroundColor = nil
+			return false
 		case bold, italic, underline, overline:
 			ir.style = sequence
 			return false
