@@ -161,7 +161,7 @@ func TestOauthResult(t *testing.T) {
 		env.On("Cache").Return(cache)
 		env.On("HTTPRequest", url).Return([]byte(tc.JSONResponse), tc.Error)
 		env.On("HTTPRequest", tokenURL).Return([]byte(tc.TokenResponse), tc.Error)
-		env.On("Error", "OAuth", mock2.Anything).Return()
+		env.On("Error", mock2.Anything).Return()
 
 		oauth := &OAuthRequest{
 			AccessTokenKey:  accessTokenKey,
