@@ -24,7 +24,6 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/platform/cmd"
 	"github.com/jandedobbeleer/oh-my-posh/src/regex"
 
-	cpu "github.com/shirou/gopsutil/v3/cpu"
 	disk "github.com/shirou/gopsutil/v3/disk"
 	load "github.com/shirou/gopsutil/v3/load"
 	process "github.com/shirou/gopsutil/v3/process"
@@ -68,10 +67,12 @@ type Flags struct {
 	Manual        bool
 	Plain         bool
 	Primary       bool
+	HasTransient  bool
 	PromptCount   int
 	Cleared       bool
 	Version       string
 	TrueColor     bool
+	NoExitCode    bool
 }
 
 type CommandError struct {
@@ -157,9 +158,6 @@ type Memory struct {
 type SystemInfo struct {
 	// mem
 	Memory
-	// cpu
-	Times float64
-	CPU   []cpu.InfoStat
 	// load
 	Load1  float64
 	Load5  float64
@@ -747,12 +745,22 @@ func (env *Shell) Cache() Cache {
 	return env.fileCache
 }
 
-func (env *Shell) Close() {
-	defer env.Trace(time.Now())
+func (env *Shell) saveTemplateCache() {
+	// only store this when in a primary prompt
+	// and when we have a transient prompt in the config
+	canSave := env.CmdFlags.Primary && env.CmdFlags.HasTransient
+	if !canSave {
+		return
+	}
 	templateCache, err := json.Marshal(env.TemplateCache())
 	if err == nil {
 		env.fileCache.Set(TEMPLATECACHE, string(templateCache), 1440)
 	}
+}
+
+func (env *Shell) Close() {
+	defer env.Trace(time.Now())
+	env.saveTemplateCache()
 	env.fileCache.Close()
 }
 
@@ -923,16 +931,6 @@ func (env *Shell) SystemInfo() (*SystemInfo, error) {
 		s.Load15 = loadStat.Load15
 	}
 
-	processorTimes, err := cpu.Percent(0, false)
-	if err == nil && len(processorTimes) > 0 {
-		s.Times = processorTimes[0]
-	}
-
-	processors, err := cpu.Info()
-	if err == nil {
-		s.CPU = processors
-	}
-
 	diskIO, err := disk.IOCounters()
 	if err == nil {
 		s.Disks = diskIO
