@@ -108,6 +108,7 @@ module.exports = {
         "segments/sapling",
         "segments/session",
         "segments/shell",
+        "segments/sitecore",
         "segments/spotify",
         "segments/strava",
         "segments/svn",
@@ -118,6 +119,7 @@ module.exports = {
         "segments/time",
         "segments/ui5tooling",
         "segments/unity",
+        "segments/upgrade",
         "segments/vala",
         "segments/wakatime",
         "segments/withings",
